package com.usky.dxtop.service.job;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.emun.OrderStatus;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author yq
 * @date 2021/8/30 16:57
 */
@Slf4j
@Component
public class OrderJob {

    @Autowired
    private OrderService orderService;

    @Scheduled(cron = "0 */1 * * * ?")
    public void execute(){
        boolean isNext = true;
        int index = 1;
        while(isNext){
            IPage<Order> page = new Page<>(index,20);
            LambdaQueryWrapper<Order> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.eq(Order::getOrderFlag, OrderStatus.NO_PAYMENT.getCode())
                    .or()
                    .eq(Order::getOrderFlag, OrderStatus.AWAIT_PAY.getCode());
            page = orderService.page(page, queryWrapper);
            List<Order> list = page.getRecords();
            log.info("---orderJob---本次处理记录:"+ list.size());
            if (CollectionUtils.isNotEmpty(list)){
                for (Order order:page.getRecords()) {
                    try {
                        orderService.callTopFindOrderInfoApi(order.getOrderNumber());
                    }catch (Exception e){
                        log.error("---orderJob---异常"+e.getMessage());
                    }
                }
                index++;
            }else {
                isNext = false;
            }
        }
        log.info("---orderJob---处理完成");
    }
}
